@@ -1,15 +1,15 @@
 from django import forms
 
 from ...models.image import UploadedImage
-from .base import UploadedFileBaseForm
+from .base import ChangeFileResourceDialogBase
 
 
-class UploadedImageDialog(UploadedFileBaseForm):
+class ChangeUploadedImageDialog(ChangeFileResourceDialogBase):
     class Meta:
         model = UploadedImage
-        fields = ("new_name", "title", "description")
+        fields = ["new_name", "title", "description"]
         widgets = {
             "description": forms.Textarea(attrs={
-                "rows": 3
+                "rows": 2
             })
         }
